(this["webpackJsonpstreamlit-google-geochart"]=this["webpackJsonpstreamlit-google-geochart"]||[]).push([[0],{25:function(e,t,a){"use strict";a.r(t);var r=a(11),i=a(6),o=a.n(i),c=a(14),s=a.n(c),n=a(4),u=a(3),l=a(8),b=a(10),p={height:"100%"};var g=Object(l.b)((function(e){var t=e.args,a=t.googleMapsApiKey,o=t.data,c=t.options,s=Object(i.useRef)(null),g=Object(i.useState)(),h=Object(u.a)(g,2),j=h[0],d=h[1],O=Object(i.useState)(),f=Object(u.a)(O,2),m=f[0],v=f[1];Object(i.useEffect)((function(){b.a.load(y,{packages:["geochart"],mapsApiKey:a})}),[]),Object(i.useEffect)((function(){var e;if(b.a.api){try{e=b.a.api.visualization.arrayToDataTable(o),v(!1),m&&l.a.setComponentValue({})}catch(t){m||(j.clearChart(),l.a.setComponentValue({error:"Google Charts: unable to parse data"}),v(!0),l.a.setFrameHeight())}j&&e&&(j.draw(e,Object(n.a)(Object(n.a)({},p),c)),b.a.api.visualization.events.addListener(j,"ready",l.a.setFrameHeight),setTimeout(l.a.setFrameHeight,200))}}));var y=function(){d(new b.a.api.visualization.GeoChart(s.current))};return Object(r.jsx)("div",{id:"chart",ref:s})}));s.a.render(Object(r.jsx)(o.a.StrictMode,{children:Object(r.jsx)(g,{})}),document.getElementById("root"))}},[[25,1,2]]]);
//# sourceMappingURL=main.de9c3825.chunk.js.map